<?php
// $Header: /cvsroot/tikiwiki/tiki/lib/calendar/Attic/display_class.php,v 1.1.2.2 2008/02/21 22:36:56 lphuberdeau Exp $
//
// Copyright (c)2002-2003
// Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
// All Rights Reserved. See copyright.txt for details and a complete list of
// authors. Licensed under the GNU LESSER GENERAL PUBLIC LICENSE.
// See license.txt for details.

// This script may only be included! Die if called directly...
if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
	header("location: index.php");
	exit;
}

/** display_class Encompases display functions that incorporate HTML in 
 * modules.  Extends the CalendarLib class.
 */
class display_class extends CalendarLib {

	// Constructor for the display_class library.
	function display_class() {

		// Do nothing at the moment.
	}

/*
 * Common Calendar Display functions.
 */

}

?>

